From 9f283236e094570a8a51947db46b94a5f36da369 Mon Sep 17 00:00:00 2001
From: Craig Ringer <craig@2ndquadrant.com>
Date: Wed, 18 Dec 2019 14:39:14 +0800
Subject: [PATCH v1] Rewrite the yum repo makefile

---
 rpm/redhat/common/Makefile.global             | 324 ++++++++++++++++--
 rpm/redhat/common/Makefile.global-PG10        | 110 ------
 .../common/Makefile.global-PG10-testing       | 110 ------
 rpm/redhat/common/Makefile.global-PG11        | 110 ------
 .../common/Makefile.global-PG11-testing       | 110 ------
 rpm/redhat/common/Makefile.global-PG12        | 110 ------
 .../common/Makefile.global-PG12-testing       | 110 ------
 .../common/Makefile.global-PG13-testing       | 110 ------
 rpm/redhat/common/Makefile.global-PG92        | 103 ------
 rpm/redhat/common/Makefile.global-PG93        | 103 ------
 rpm/redhat/common/Makefile.global-PG94        | 103 ------
 rpm/redhat/common/Makefile.global-PG95        | 103 ------
 rpm/redhat/common/Makefile.global-PG96        | 110 ------
 .../common/Makefile.global-PG96-testing       | 110 ------
 14 files changed, 299 insertions(+), 1427 deletions(-)
 delete mode 100644 rpm/redhat/common/Makefile.global-PG10
 delete mode 100644 rpm/redhat/common/Makefile.global-PG10-testing
 delete mode 100644 rpm/redhat/common/Makefile.global-PG11
 delete mode 100644 rpm/redhat/common/Makefile.global-PG11-testing
 delete mode 100644 rpm/redhat/common/Makefile.global-PG12
 delete mode 100644 rpm/redhat/common/Makefile.global-PG12-testing
 delete mode 100644 rpm/redhat/common/Makefile.global-PG13-testing
 delete mode 100644 rpm/redhat/common/Makefile.global-PG92
 delete mode 100644 rpm/redhat/common/Makefile.global-PG93
 delete mode 100644 rpm/redhat/common/Makefile.global-PG94
 delete mode 100644 rpm/redhat/common/Makefile.global-PG95
 delete mode 100644 rpm/redhat/common/Makefile.global-PG96
 delete mode 100644 rpm/redhat/common/Makefile.global-PG96-testing

diff --git a/rpm/redhat/common/Makefile.global b/rpm/redhat/common/Makefile.global
index 5281a2b9d..3b6c8e2bd 100644
--- a/rpm/redhat/common/Makefile.global
+++ b/rpm/redhat/common/Makefile.global
@@ -6,39 +6,313 @@
 # Devrim Gunduz		   	#
 # devrim@gunduz.org	   	#
 #################################
-#			 	#
-#				#
-# build target is for      	#
-# RPM buildfarm		   	#
-#			   	#
-#			   	#
-#################################
+#
+# 'build' target is for RPM buildfarm
+#
+# The build targets are all for use via the Makefile in each subdirectory.
+# There are base targets like 'rpm' that detect the target PostgreSQL based on
+# the path being built on, and there are version-qualified targets that specify
+# a Pg version explicitly like rpm12. These are listed as "rpmNN" etc below.
+#
+# Targets:
+#
+#     clean
+#       Remove all build products
+#
+#     prep
+#     prepNN
+#       Download sources etc
+#
+#     rpm
+#     rpmNN (where "NN" is the Pg major)
+#       build rpm and output in CWD
+#
+#     srpm
+#     srpmNN
+#       build srpm and output in CWD
+#
+#     build
+#     buildNN
+#       build both rpm and srpm and output in $HOME/rpmNN
+#
+# There are variants of the rpm, srpm and build targets that are prefixed
+# with 'nosign' and/or 'noprep', and/or suffixed 'testing', e.g.
+#
+#     nosignrpm12
+#     nosignnopreprpm12testing
+#
+# The 'nosign' variants skip rpm signing. The 'noprep' variants don't run the
+# 'prep' step implicitly. The 'testing' targets just use a different build tree
+# with 'testing' suffix. In most cases you should ignore all of them and prefer
+# to set the variables TESTING=1, SIGN_FLAGS="" and PREP=0 as appropriate.
+#
+# User-settable variables at make command line:
+#
+#    PREP=0
+#       suppress dependency downloads (otherwise done by default)
+#       Same as using 'noprep' target prefix.
+#
+#    TESTING=1
+#       suffix build with 'testing'. Same as using 'testing'
+#       target suffix.
+#
+#    USE_GIT_PULL=0
+#       suppress automatic "git pull" during package
+#       build prep.
+#
+#    GIT
+#       Command to use for git. You can add extra args here too.
+#
+#    INSTALL_DEPENDS=1
+#       do an automatic "yum builddep" or "dnf build-dep"
+#       for a package's spec file before building it.
+#
+#    SIGN_FLAGS=--sign
+#       Override default "--sign" flags for signing or supply your own.
+#       You can pass SIGN_FLAGS= to skip signing.
+#
+#    EXTRA_RPM_MACROS=--define "foo bar"
+#       pass extra macros to rpm commands. Note this doesn't
+#       work for the builddep step on EL-6; there you will have
+#       to add to $HOME/.rpmmacros manually.
+#
+#
+#
 
-prep:
-	if [ -f dead.package ]; then echo "This package is marked as dead. Build won't continue"; exit 1; fi
+# Pg versions to generate targets for
+PG_MAJOR_VERSIONS ?= 9.2 9.3 9.4 9.5 9.6 10 11 12
 
-	# Update spec file, patches, etc, before running spectool:
-	git pull
+# Detect what we're building
+ARCH ?= $(shell rpm --eval "%{_arch}")
+SPECFILE=$(wildcard *.spec)
 
-	# Use spectool to download source files, especially tarballs.
-	spectool -g -S $(SPECFILE)
+# Determine product etc from path if possible. Paths are e.g.:
+#
+# rpm/redhat/12/geos36/EL-6
+#
+# distcode and/or pgver could be 'master' if we're being invoked
+# directly from one of the shared directories. For DIST the user
+# should then suppply it. For PGVER we'll generate make targets
+# for all versions for now anyway.
+#
+# The remaining path is assigned to 'rest' at each step then the trailing
+# slash stripped with substitution references.
+#
+PATH_DISTCODE=$(subst -,_,$(notdir $(PWD)))
+rest:=$(dir $(PWD))
+rest:=$(rest:/=)
+PATH_PKGNAME=$(notdir $(rest))
+rest:=$(dir $(rest))
+rest:=$(rest:/=)
+PATH_PGVER=$(notdir $(rest))
+
+# If the path has a Pg major version on it, make convenient targets 'rpm', 'srpm'
+# and 'build':
+#
+ifneq ($(findstring $(PATH_PGVER),$(PG_MAJOR_VERSIONS)),)
+$(info 'make rpm', 'make srpm' and 'make build' will target postgres $(PATH_PGVER))
+tprefix:=$(if $(subst 0,,$(SIGN)),nosign)$(if $(subst 0,,$(PREP)),noprep)
+tsuffix:=$(subst .,,$(PATH_PGVER))$(if $(subst 0,,$(TESTING)),testing,)
+default: $(tprefix)build$(tsuffix)
+rpm: $(tprefix)rpm$(tsuffix)
+srpm: $(tprefix)rpm$(tsuffix)
+build: $(tprefix)build$(tsuffix)
+tprefix:=
+tsuffix:=
+else
+default: build
+rpm srpm build:
+	$(error you need to use targets with a version suffix like rpm12 or build12)
+endif
+
+# Variables to map dir names like EL-8 to DIST suffixes like .rhel8
+#
+# Computed varnames are used to allow for the weird and wonderful variety
+# of DIST names seen in the wild, and so users can override them with command
+# line assignment.
+#
+# define vars like DIST_EL-5=.rhel5
+$(foreach rhelver,5 6,\
+  $(eval DIST_EL_$(rhelver) := .rhel$(rhelver)) \
+)
+# define vars like DIST_F-30=.f30
+$(foreach fedoraver,30 31,\
+  $(eval DIST_F_$(fedoraver):=.f$(fedoraver)) \
+)
+# Define vars like DIST_SLES-12=.sles12
+$(foreach slesver,12,\
+  $(eval DIST_SLES_$(slesver):=.f$(slesver)) \
+)
+
+ifndef DIST
+  DIST := $(DIST_$(PATH_DISTCODE))
+endif
+
+ifeq ($(DIST),)
+  $(error No DIST set in including Makefile and no var named DIST_$(PATH_DISTCODE) defined. Supply DIST on command line.)
+else
+  $(info Building for DIST=$(DIST))
+endif
+
+USE_GIT_PULL ?= 1
+GIT ?= git
+ifeq ($(USE_GIT_PULL),1)
+  git_pull ?= $(GIT) pull
+else
+  git_pull ?=
+endif
+
+INSTALL_DEPENDS ?= 0
+ifneq ($(INSTALL_DEPENDS),0)
+  ifneq ($(shell test -e /usr/bin/dnf),)
+    # Requires dnf-plugins-core package
+    install_builddep_spec = dnf build-dep -y $$(SPECFILE)
+    nodeps =
+  else
+    # requires yum-utils package
+    install_builddep_spec = yum-builddep -y $$(SPECFILE)
+    nodeps =
+  endif
+else
+  install_builddep_spec =
+  nodeps = --nodeps
+endif
+
+SIGN_FLAGS ?= --sign
+
+dead_package_test = if [ -f dead.package ]; then echo "This package is marked as dead. Build won't continue"; exit 1; fi
+
+# macros to pass to rpm commands. Note that this is a lazy(recursive) variable
+# on purpose; it's expanded in the context of each templated set of targets
+# with a different set of versions.
+EXTRA_RPM_MACROS ?=
 
 allclean:
-	git clean -dfx
+	$(GIT) clean -dfx
 
 clean:
 	rm -rf i386/ i586/ i686/ x86_64/ noarch/
 	rm -f *.src.rpm
 	rm -f *.tar *.tar.gz *.tar.bz2 *.tgz *.zip .xz
 
-include ../../../common/Makefile.global-PG93
-include ../../../common/Makefile.global-PG94
-include ../../../common/Makefile.global-PG95
-include ../../../common/Makefile.global-PG96
-include ../../../common/Makefile.global-PG96-testing
-include ../../../common/Makefile.global-PG10-testing
-include ../../../common/Makefile.global-PG10
-include ../../../common/Makefile.global-PG11-testing
-include ../../../common/Makefile.global-PG11
-include ../../../common/Makefile.global-PG12-testing
-include ../../../common/Makefile.global-PG12
+# Template for make targets for Pg versions.
+#
+# $(call) supplies numbered arguments which are rather inconvenient. So instead
+# we set simple variables with := in the innermost loop of the foreach that expands
+# this template, giving us named arguments, and we $(eval) the result.
+#
+# The doubling of $(var) expansion is needed wherever the first pass that reads
+# the defineed variable would otherwise eagerly expand variables. We don't want
+# derived vars to be expanded until after $(1) etc are set by $(call) during
+# $(foreach) expansion below then the generated body evaluated with $(eval).
+#
+# Use 'make -d' and 'make -p' for debugging. You may also find it useful to
+# replace the $(eval $(call)) with $(info $(call)) to log the generated body
+# rather than execute it. To see generated targets run
+#
+#     make -p 2>&1 | egrep '^[a-z][^=]*:[^=]'| cut -d : -f 1  | sort -u
+#
+# since for some bizarre reason make doesn't support dumping target names.
+#
+define version_targets
+
+# For debugging, uncomment this:
+#$$(info generating target for major=$$(major) ($$(nodotmajor)) with options: $$(filter-out ,$$(nosign) $$(noprep) $$(testing)))
+
+# variant suffix to use for variables to avoid clashes.
+v := $$(nodotmajor)$$(nosign)$$(noprep)$$(testing)
+
+# macros to define for all the build variants
+rpmmacros$$(v) := \
+	    --define "_sourcedir $(PWD)" \
+	    --define "_specdir $(PWD)" \
+	    --define "dist $(DIST)" \
+	    --define "pginstdir /usr/pgsql-$$(major)" \
+	    --define "pgmajorversion $$(nodotmajor)" \
+	    --define "pgpackageversion $$(major)" \
+	    $(EXTRA_RPM_MACROS)
+
+# Output everything to the rpmbasedir, for 'build' targets
+rpmbasedir := $(HOME)/rpm$$(nodotmajor)$$(testing)
+rpmdirs_buildroot$$(v) := \
+	    --define "_builddir $$(rpmbasedir)/BUILD" \
+	    --define "_buildrootdir $$(rpmbasedir)/BUILDROOT" \
+	    --define "_rpmdir $$(rpmbasedir)/RPMS/" \
+	    --define "_srcrpmdir $$(rpmbasedir)/SRPMS"
+
+# Build in cwd subdirs, output to cwd, for 'rpm' and 'srpm' targets
+rpmdirs_cwd$$(v) := \
+	    --define "_builddir $(PWD)rpm$$(nodotmajor)$$(testing)/BUILD" \
+	    --define "_buildrootdir $(PWD)rpm$$(nodotmajor)$$(testing)/BUILDROOT" \
+	    --define "_rpmdir $(PWD)" \
+	    --define "_srcrpmdir $(PWD)"
+
+# target name fragments for generating the noprep and nosign variants
+prep_target := $$(if $$(filter noprep,$$(noprep)),,prep$$(nodotmajor))
+
+# We only need one definition of the prep test but it's simpler to define
+# them for all cases since ifeq is expanded eagerly on the first pass
+# and inline if is inconvenient for targets with recipes.
+ifeq ($$(nosign)$$(noprep)$$(testing),)
+$$(prep_target):
+	@$(dead_package_test)
+	# Update spec file, patches, etc, before running spectool:
+	$(git_pull)
+	# Use spectool to download source files, especially tarballs.
+	spectool -g -S $(rpmmacros) $(SPECFILE)
+	# If requested, install build-depends from the specfile.
+	$(install_builddep_spec)
+
+alltargets .PHONY: $$(prep_target)
+endif
+
+# Combined source and build step that forces source step to run and
+# output to the rpmbasedir.
+$$(nosign)$$(noprep)build$$(nodotmajor)$$(testing): $$(prep_target)
+	rpmbuild $$(rpmmacros$(v)) $$(rpmdirs_buildroot$(v)) $(sign_flag) $(nodeps) -bs $(SPECFILE)
+	rpmbuild $$(rpmmacros$(v)) $$(rpmdirs_buildroot$(v)) $(sign_flag) $(nodeps) -bb $(SPECFILE)
+
+# Build just the srpm and output to PWD
+$$(nosign)$$(noprep)srpm$$(nodotmajor)$$(testing): $$(prep_target)
+	rpmbuild $$(rpmmacros$(v)) $$(rpmdirs_cwd$(v)) $(sign_flag) $(nodeps) -bs $(SPECFILE)
+
+# build just the rpm and output to PWD
+$$(nosign)$$(noprep)rpm$$(nodotmajor)$$(testing): $$(prep_target)
+	 rpmbuild $$(rpmmacros$(v)) $$(rpmdirs_cwd$(v)) $(sign_flag) $(nodeps) -bb $(SPECFILE)
+
+alltargets .PHONY: \
+    $$(nosign)$$(noprep)build$$(nodotmajor)$$(testing) \
+    $$(nosign)$$(noprep)srpm$$(nodotmajor)$$(testing) \
+    $$(nosign)$$(noprep)rpm$$(nodotmajor)$$(testing)
+
+# Clear vars to help prevent mistakes
+major:=
+nodotmajor:=
+nosign:=
+noprep:=
+testing:=
+
+endef
+
+# Generate targets for each major version with nosign and noprep variants and testing
+# variants of all of them.
+#
+# Use of 'sign', 'prep' etc works around the inability to specify the empty
+# string as one of the entries in a foreach by passing placeholders "prep",
+# "sign" or "notesting" when we want empty, then filtering them out.
+#
+$(foreach pgmajorversion,$(PG_MAJOR_VERSIONS),\
+  $(foreach signvariant,sign nosign,\
+    $(foreach prepvariant,prep noprep,\
+      $(foreach testingvariant,notesting testing,\
+	    $(eval major := $(pgmajorversion)) \
+		$(eval nodotmajor := $$(subst .,,$$(major))) \
+		$(eval nosign := $$(filter-out sign,$(signvariant))) \
+		$(eval noprep := $$(filter-out prep,$(prepvariant))) \
+		$(eval testing := $$(filter-out notesting,$(testingvariant))) \
+		$(eval sign_flag := $$(if $$(nosign),,$(SIGN_FLAGS))) \
+        $(eval $(version_targets)) \
+      ) \
+    ) \
+  ) \
+)
diff --git a/rpm/redhat/common/Makefile.global-PG10 b/rpm/redhat/common/Makefile.global-PG10
deleted file mode 100644
index c5f977c4e..000000000
--- a/rpm/redhat/common/Makefile.global-PG10
+++ /dev/null
@@ -1,110 +0,0 @@
-#################################
-# Makefile for PostgreSQL 10	#
-# packaging	  	 	#
-# https://yum.postgresql.org	#
-#			   	#
-# Devrim Gunduz		   	#
-# devrim@gunduz.org	   	#
-#################################
-#			 	#
-#				#
-# build target is for      	#
-# RPM buildfarm		   	#
-#			   	#
-#			   	#
-#################################
-
-
-## PostgreSQL 10
-
-prep10:
-	if [ -f dead.package ]; then echo "This package is marked as dead. Build won't continue"; exit 1; fi
-	# Update spec file, patches, etc, before running spectool:
-	git pull
-	# Use spectool to download source files, especially tarballs.
-	spectool -g -S --define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10" --define "pgpackageversion 10" $(SPECFILE)
-
-build10: bfsrpm10
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm10/BUILDROOT" \
-	--define "_builddir $(HOME)/rpm10/BUILD" \
-	--define "_srcrpmdir $(HOME)/rpm10/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm10/RPMS/" --sign \
-	--define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10" --define "pgpackageversion 10" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-srpm10: prep10
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." --sign \
-	--define "_buildrootdir $(HOME)/rpm10/BUILDROOT" \
-	--define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10"  --define "pgpackageversion 10" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfsrpm10: prep10
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm10/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm10/BUILDROOT" \
-	--define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10"  --define "pgpackageversion 10" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfnosignsrpm10: prep10
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_buildrootdir $(HOME)/rpm10/BUILDROOT" \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm10/SRPMS" \
-	--define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10"  --define "pgpackageversion 10" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-rpm10: prep10
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm10/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10" --define "pgpackageversion 10" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nosignbuild10: bfnosignsrpm10
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm10/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm10/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm10/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm10/RPMS/" \
-	--define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10" --define "pgpackageversion 10" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepbuild10:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm10/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm10/BUILDROOT" \
-	--define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10" --define "pgpackageversion 10" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm10/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm10/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm10/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm10/RPMS/" --sign \
-	--define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10" --define "pgpackageversion 10" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nopreprpm10:
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm10/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10" --define "pgpackageversion 10" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepsrpm10:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." \
-	--define "_buildrootdir $(HOME)/rpm10/BUILDROOT" \
-	--define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10" --define "pgpackageversion 10" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
diff --git a/rpm/redhat/common/Makefile.global-PG10-testing b/rpm/redhat/common/Makefile.global-PG10-testing
deleted file mode 100644
index 9b33b640f..000000000
--- a/rpm/redhat/common/Makefile.global-PG10-testing
+++ /dev/null
@@ -1,110 +0,0 @@
-#################################
-# Makefile for PostgreSQL 10	#
-# testing packaging	 	#
-# https://yum.postgresql.org	#
-#			   	#
-# Devrim Gunduz		   	#
-# devrim@gunduz.org	   	#
-#################################
-#			 	#
-#				#
-# build target is for      	#
-# RPM buildfarm		   	#
-#			   	#
-#			   	#
-#################################
-
-
-## PostgreSQL 10 Testing
-
-prep10testing:
-	if [ -f dead.package ]; then echo "This package is marked as dead. Build won't continue"; exit 1; fi
-	# Update spec file, patches, etc, before running spectool:
-	git pull
-	# Use spectool to download source files, especially tarballs.
-	spectool -g -S --define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10" --define "pgpackageversion 10" $(SPECFILE)
-
-build10testing: bfsrpm10testing
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm10testing/BUILDROOT" \
-	--define "_builddir $(HOME)/rpm10testing/BUILD" \
-	--define "_srcrpmdir $(HOME)/rpm10testing/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm10testing/RPMS/" --sign \
-	--define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10" --define "pgpackageversion 10" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-srpm10testing: prep10
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." --sign \
-	--define "_buildrootdir $(HOME)/rpm10testing/BUILDROOT" \
-	--define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10"  --define "pgpackageversion 10" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfsrpm10testing: prep10
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm10testing/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm10testing/BUILDROOT" \
-	--define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10"  --define "pgpackageversion 10" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfnosignsrpm10testing: prep10
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_buildrootdir $(HOME)/rpm10testing/BUILDROOT" \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm10testing/SRPMS" \
-	--define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10"  --define "pgpackageversion 10" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-rpm10testing: prep10
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm10testing/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10" --define "pgpackageversion 10" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nosignbuild10testimg: bfnosignsrpm10testing
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm10testing/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm10testing/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm10testing/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm10testing/RPMS/" \
-	--define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10" --define "pgpackageversion 10" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepbuild10testing:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm10testing/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm10testing/BUILDROOT" \
-	--define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10" --define "pgpackageversion 10" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm10testing/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm10testing/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm10testing/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm10testing/RPMS/" --sign \
-	--define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10" --define "pgpackageversion 10" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nopreprpm10testing:
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm10testing/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10" --define "pgpackageversion 10" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepsrpm10testing:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." \
-	--define "_buildrootdir $(HOME)/rpm10testing/BUILDROOT" \
-	--define "pgmajorversion 10" --define "pginstdir /usr/pgsql-10" --define "pgpackageversion 10" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
diff --git a/rpm/redhat/common/Makefile.global-PG11 b/rpm/redhat/common/Makefile.global-PG11
deleted file mode 100644
index d680df532..000000000
--- a/rpm/redhat/common/Makefile.global-PG11
+++ /dev/null
@@ -1,110 +0,0 @@
-#################################
-# Makefile for PostgreSQL 11	#
-# packaging	  	 	#
-# https://yum.postgresql.org	#
-#			   	#
-# Devrim Gunduz		   	#
-# devrim@gunduz.org	   	#
-#################################
-#			 	#
-#				#
-# build target is for      	#
-# RPM buildfarm		   	#
-#			   	#
-#			   	#
-#################################
-
-
-## PostgreSQL 11
-
-prep11:
-	if [ -f dead.package ]; then echo "This package is marked as dead. Build won't continue"; exit 1; fi
-	# Update spec file, patches, etc, before running spectool:
-	git pull
-	# Use spectool to download source files, especially tarballs.
-	spectool -g -S --define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11" --define "pgpackageversion 11" $(SPECFILE)
-
-build11: bfsrpm11
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm11/BUILDROOT" \
-	--define "_builddir $(HOME)/rpm11/BUILD" \
-	--define "_srcrpmdir $(HOME)/rpm11/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm11/RPMS/" --sign \
-	--define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11" --define "pgpackageversion 11" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-srpm11: prep11
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." --sign \
-	--define "_buildrootdir $(HOME)/rpm11/BUILDROOT" \
-	--define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11"  --define "pgpackageversion 11" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfsrpm11: prep11
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm11/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm11/BUILDROOT" \
-	--define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11"  --define "pgpackageversion 11" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfnosignsrpm11: prep11
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_buildrootdir $(HOME)/rpm11/BUILDROOT" \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm11/SRPMS" \
-	--define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11"  --define "pgpackageversion 11" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-rpm11: prep11
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm11/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11" --define "pgpackageversion 11" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nosignbuild11: bfnosignsrpm11
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm11/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm11/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm11/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm11/RPMS/" \
-	--define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11" --define "pgpackageversion 11" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepbuild11:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm11/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm11/BUILDROOT" \
-	--define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11" --define "pgpackageversion 11" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm11/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm11/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm11/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm11/RPMS/" --sign \
-	--define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11" --define "pgpackageversion 11" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nopreprpm11:
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm11/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11" --define "pgpackageversion 11" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepsrpm11:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." \
-	--define "_buildrootdir $(HOME)/rpm11/BUILDROOT" \
-	--define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11" --define "pgpackageversion 11" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
diff --git a/rpm/redhat/common/Makefile.global-PG11-testing b/rpm/redhat/common/Makefile.global-PG11-testing
deleted file mode 100644
index 81aa37a90..000000000
--- a/rpm/redhat/common/Makefile.global-PG11-testing
+++ /dev/null
@@ -1,110 +0,0 @@
-#################################
-# Makefile for PostgreSQL 11	#
-# testing packaging	 	#
-# https://yum.postgresql.org	#
-#			   	#
-# Devrim Gunduz		   	#
-# devrim@gunduz.org	   	#
-#################################
-#			 	#
-#				#
-# build target is for      	#
-# RPM buildfarm		   	#
-#			   	#
-#			   	#
-#################################
-
-
-## PostgreSQL 11 Testing
-
-prep11testing:
-	if [ -f dead.package ]; then echo "This package is marked as dead. Build won't continue"; exit 1; fi
-	# Update spec file, patches, etc, before running spectool:
-	git pull
-	# Use spectool to download source files, especially tarballs.
-	spectool -g -S --define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11" --define "pgpackageversion 11" $(SPECFILE)
-
-build11testing: bfsrpm11testing
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm11testing/BUILDROOT" \
-	--define "_builddir $(HOME)/rpm11testing/BUILD" \
-	--define "_srcrpmdir $(HOME)/rpm11testing/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm11testing/RPMS/" --sign \
-	--define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11" --define "pgpackageversion 11" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-srpm11testing: prep11
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." --sign \
-	--define "_buildrootdir $(HOME)/rpm11testing/BUILDROOT" \
-	--define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11"  --define "pgpackageversion 11" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfsrpm11testing: prep11
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm11testing/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm11testing/BUILDROOT" \
-	--define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11"  --define "pgpackageversion 11" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfnosignsrpm11testing: prep11
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_buildrootdir $(HOME)/rpm11testing/BUILDROOT" \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm11testing/SRPMS" \
-	--define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11"  --define "pgpackageversion 11" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-rpm11testing: prep11
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm11testing/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11" --define "pgpackageversion 11" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nosignbuild11testimg: bfnosignsrpm11testing
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm11testing/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm11testing/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm11testing/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm11testing/RPMS/" \
-	--define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11" --define "pgpackageversion 11" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepbuild11testing:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm11testing/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm11testing/BUILDROOT" \
-	--define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11" --define "pgpackageversion 11" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm11testing/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm11testing/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm11testing/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm11testing/RPMS/" --sign \
-	--define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11" --define "pgpackageversion 11" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nopreprpm11testing:
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm11testing/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11" --define "pgpackageversion 11" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepsrpm11testing:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." \
-	--define "_buildrootdir $(HOME)/rpm11testing/BUILDROOT" \
-	--define "pgmajorversion 11" --define "pginstdir /usr/pgsql-11" --define "pgpackageversion 11" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
diff --git a/rpm/redhat/common/Makefile.global-PG12 b/rpm/redhat/common/Makefile.global-PG12
deleted file mode 100644
index d19f6c7a8..000000000
--- a/rpm/redhat/common/Makefile.global-PG12
+++ /dev/null
@@ -1,110 +0,0 @@
-#################################
-# Makefile for PostgreSQL 12	#
-# packaging	  	 	#
-# https://yum.postgresql.org	#
-#			   	#
-# Devrim Gunduz		   	#
-# devrim@gunduz.org	   	#
-#################################
-#			 	#
-#				#
-# build target is for      	#
-# RPM buildfarm		   	#
-#			   	#
-#			   	#
-#################################
-
-
-## PostgreSQL 12
-
-prep12:
-	if [ -f dead.package ]; then echo "This package is marked as dead. Build won't continue"; exit 1; fi
-	# Update spec file, patches, etc, before running spectool:
-	git pull
-	# Use spectool to download source files, especially tarballs.
-	spectool -g -S --define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12" --define "pgpackageversion 12" $(SPECFILE)
-
-build12: bfsrpm12
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm12/BUILDROOT" \
-	--define "_builddir $(HOME)/rpm12/BUILD" \
-	--define "_srcrpmdir $(HOME)/rpm12/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm12/RPMS/" --sign \
-	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12" --define "pgpackageversion 12" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-srpm12: prep12
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." --sign \
-	--define "_buildrootdir $(HOME)/rpm12/BUILDROOT" \
-	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12"  --define "pgpackageversion 12" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfsrpm12: prep12
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm12/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm12/BUILDROOT" \
-	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12"  --define "pgpackageversion 12" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfnosignsrpm12: prep12
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_buildrootdir $(HOME)/rpm12/BUILDROOT" \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm12/SRPMS" \
-	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12"  --define "pgpackageversion 12" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-rpm12: prep12
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm12/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12" --define "pgpackageversion 12" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nosignbuild12: bfnosignsrpm12
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm12/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm12/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm12/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm12/RPMS/" \
-	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12" --define "pgpackageversion 12" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepbuild12:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm12/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm12/BUILDROOT" \
-	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12" --define "pgpackageversion 12" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm12/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm12/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm12/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm12/RPMS/" --sign \
-	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12" --define "pgpackageversion 12" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nopreprpm12:
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm12/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12" --define "pgpackageversion 12" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepsrpm12:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." \
-	--define "_buildrootdir $(HOME)/rpm12/BUILDROOT" \
-	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12" --define "pgpackageversion 12" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
diff --git a/rpm/redhat/common/Makefile.global-PG12-testing b/rpm/redhat/common/Makefile.global-PG12-testing
deleted file mode 100644
index 4c0f12ad7..000000000
--- a/rpm/redhat/common/Makefile.global-PG12-testing
+++ /dev/null
@@ -1,110 +0,0 @@
-#################################
-# Makefile for PostgreSQL 12	#
-# testing packaging	 	#
-# https://yum.postgresql.org	#
-#			   	#
-# Devrim Gunduz		   	#
-# devrim@gunduz.org	   	#
-#################################
-#			 	#
-#				#
-# build target is for      	#
-# RPM buildfarm		   	#
-#			   	#
-#			   	#
-#################################
-
-
-## PostgreSQL 12 Testing
-
-prep12testing:
-	if [ -f dead.package ]; then echo "This package is marked as dead. Build won't continue"; exit 1; fi
-	# Update spec file, patches, etc, before running spectool:
-	git pull
-	# Use spectool to download source files, especially tarballs.
-	spectool -g -S --define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12" --define "pgpackageversion 12" $(SPECFILE)
-
-build12testing: bfsrpm12testing
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm12testing/BUILDROOT" \
-	--define "_builddir $(HOME)/rpm12testing/BUILD" \
-	--define "_srcrpmdir $(HOME)/rpm12testing/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm12testing/RPMS/" --sign \
-	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12" --define "pgpackageversion 12" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-srpm12testing: prep
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." --sign \
-	--define "_buildrootdir $(HOME)/rpm12testing/BUILDROOT" \
-	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12"  --define "pgpackageversion 12" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfsrpm12testing: prep
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm12testing/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm12testing/BUILDROOT" \
-	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12"  --define "pgpackageversion 12" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfnosignsrpm12testing: prep
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_buildrootdir $(HOME)/rpm12testing/BUILDROOT" \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm12testing/SRPMS" \
-	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12"  --define "pgpackageversion 12" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-rpm12testing: prep
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm12testing/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12" --define "pgpackageversion 12" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nosignbuild12testimg: bfnosignsrpm12testing
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm12testing/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm12testing/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm12testing/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm12testing/RPMS/" \
-	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12" --define "pgpackageversion 12" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepbuild12testing:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm12testing/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm12testing/BUILDROOT" \
-	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12" --define "pgpackageversion 12" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm12testing/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm12testing/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm12testing/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm12testing/RPMS/" --sign \
-	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12" --define "pgpackageversion 12" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nopreprpm12testing:
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm12testing/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12" --define "pgpackageversion 12" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepsrpm12testing:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." \
-	--define "_buildrootdir $(HOME)/rpm12testing/BUILDROOT" \
-	--define "pgmajorversion 12" --define "pginstdir /usr/pgsql-12" --define "pgpackageversion 12" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
diff --git a/rpm/redhat/common/Makefile.global-PG13-testing b/rpm/redhat/common/Makefile.global-PG13-testing
deleted file mode 100644
index 18202b0ae..000000000
--- a/rpm/redhat/common/Makefile.global-PG13-testing
+++ /dev/null
@@ -1,110 +0,0 @@
-#################################
-# Makefile for PostgreSQL 13	#
-# testing packaging	 	#
-# https://yum.postgresql.org	#
-#			   	#
-# Devrim Gunduz		   	#
-# devrim@gunduz.org	   	#
-#################################
-#			 	#
-#				#
-# build target is for      	#
-# RPM buildfarm		   	#
-#			   	#
-#			   	#
-#################################
-
-
-## PostgreSQL 13 Testing
-
-prep13testing:
-	if [ -f dead.package ]; then echo "This package is marked as dead. Build won't continue"; exit 1; fi
-	# Update spec file, patches, etc, before running spectool:
-	git pull
-	# Use spectool to download source files, especially tarballs.
-	spectool -g -S --define "pgmajorversion 13" --define "pginstdir /usr/pgsql-13" --define "pgpackageversion 13" $(SPECFILE)
-
-build13testing: bfsrpm13testing
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm13testing/BUILDROOT" \
-	--define "_builddir $(HOME)/rpm13testing/BUILD" \
-	--define "_srcrpmdir $(HOME)/rpm13testing/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm13testing/RPMS/" --sign \
-	--define "pgmajorversion 13" --define "pginstdir /usr/pgsql-13" --define "pgpackageversion 13" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-srpm13testing: prep
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." --sign \
-	--define "_buildrootdir $(HOME)/rpm13testing/BUILDROOT" \
-	--define "pgmajorversion 13" --define "pginstdir /usr/pgsql-13"  --define "pgpackageversion 13" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfsrpm13testing: prep
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm13testing/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm13testing/BUILDROOT" \
-	--define "pgmajorversion 13" --define "pginstdir /usr/pgsql-13"  --define "pgpackageversion 13" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfnosignsrpm13testing: prep
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_buildrootdir $(HOME)/rpm13testing/BUILDROOT" \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm13testing/SRPMS" \
-	--define "pgmajorversion 13" --define "pginstdir /usr/pgsql-13"  --define "pgpackageversion 13" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-rpm13testing: prep
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm13testing/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 13" --define "pginstdir /usr/pgsql-13" --define "pgpackageversion 13" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nosignbuild13testimg: bfnosignsrpm13testing
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm13testing/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm13testing/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm13testing/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm13testing/RPMS/" \
-	--define "pgmajorversion 13" --define "pginstdir /usr/pgsql-13" --define "pgpackageversion 13" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepbuild13testing:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm13testing/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm13testing/BUILDROOT" \
-	--define "pgmajorversion 13" --define "pginstdir /usr/pgsql-13" --define "pgpackageversion 13" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm13testing/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm13testing/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm13testing/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm13testing/RPMS/" --sign \
-	--define "pgmajorversion 13" --define "pginstdir /usr/pgsql-13" --define "pgpackageversion 13" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nopreprpm13testing:
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm13testing/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 13" --define "pginstdir /usr/pgsql-13" --define "pgpackageversion 13" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepsrpm13testing:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." \
-	--define "_buildrootdir $(HOME)/rpm13testing/BUILDROOT" \
-	--define "pgmajorversion 13" --define "pginstdir /usr/pgsql-13" --define "pgpackageversion 13" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
diff --git a/rpm/redhat/common/Makefile.global-PG92 b/rpm/redhat/common/Makefile.global-PG92
deleted file mode 100644
index bab3b9a7a..000000000
--- a/rpm/redhat/common/Makefile.global-PG92
+++ /dev/null
@@ -1,103 +0,0 @@
-#################################
-# Makefile for PostgreSQL 9.2	#
-# packaging	  	 	#
-# https://yum.postgresql.org	#
-#			   	#
-# Devrim Gunduz		   	#
-# devrim@gunduz.org	   	#
-#################################
-#			 	#
-#				#
-# build target is for      	#
-# RPM buildfarm		   	#
-#			   	#
-#			   	#
-#################################
-
-
-## PostgreSQL 9.2
-
-build92: bfsrpm92
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm92/BUILDROOT" \
-	--define "_builddir $(HOME)/rpm92/BUILD" \
-	--define "_srcrpmdir $(HOME)/rpm92/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm92/RPMS/" --sign \
-	--define "pgmajorversion 92" --define "pginstdir /usr/pgsql-9.2" --define "pgpackageversion 9.2" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-srpm92: prep
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." --sign \
-	--define "_buildrootdir $(HOME)/rpm92/BUILDROOT" \
-	--define "pgmajorversion 92" --define "pginstdir /usr/pgsql-9.2"  --define "pgpackageversion 9.2" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfsrpm92: prep
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm92/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm92/BUILDROOT" \
-	--define "pgmajorversion 92" --define "pginstdir /usr/pgsql-9.2"  --define "pgpackageversion 9.2" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfnosignsrpm92: prep
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_buildrootdir $(HOME)/rpm92/BUILDROOT" \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm92/SRPMS" \
-	--define "pgmajorversion 92" --define "pginstdir /usr/pgsql-9.2"  --define "pgpackageversion 9.2" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-rpm92: prep
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm92/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 92" --define "pginstdir /usr/pgsql-9.2" --define "pgpackageversion 9.2" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nosignbuild92: bfnosignsrpm92
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm92/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm92/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm92/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm92/RPMS/" \
-	--define "pgmajorversion 92" --define "pginstdir /usr/pgsql-9.2" --define "pgpackageversion 9.2" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepbuild92:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm92/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm92/BUILDROOT" \
-	--define "pgmajorversion 92" --define "pginstdir /usr/pgsql-9.2" --define "pgpackageversion 9.2" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm92/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm92/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm92/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm92/RPMS/" --sign \
-	--define "pgmajorversion 92" --define "pginstdir /usr/pgsql-9.2" --define "pgpackageversion 9.2" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nopreprpm92:
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm92/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 92" --define "pginstdir /usr/pgsql-9.2" --define "pgpackageversion 9.2" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepsrpm92:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." \
-	--define "_buildrootdir $(HOME)/rpm92/BUILDROOT" \
-	--define "pgmajorversion 92" --define "pginstdir /usr/pgsql-9.2" --define "pgpackageversion 9.2" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
diff --git a/rpm/redhat/common/Makefile.global-PG93 b/rpm/redhat/common/Makefile.global-PG93
deleted file mode 100644
index 397e729d4..000000000
--- a/rpm/redhat/common/Makefile.global-PG93
+++ /dev/null
@@ -1,103 +0,0 @@
-#################################
-# Makefile for PostgreSQL 9.3	#
-# packaging	  	 	#
-# https://yum.postgresql.org	#
-#			   	#
-# Devrim Gunduz		   	#
-# devrim@gunduz.org	   	#
-#################################
-#			 	#
-#				#
-# build target is for      	#
-# RPM buildfarm		   	#
-#			   	#
-#			   	#
-#################################
-
-
-## PostgreSQL 9.3
-
-build93: bfsrpm93
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm93/BUILDROOT" \
-	--define "_builddir $(HOME)/rpm93/BUILD" \
-	--define "_srcrpmdir $(HOME)/rpm93/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm93/RPMS/" --sign \
-	--define "pgmajorversion 93" --define "pginstdir /usr/pgsql-9.3" --define "pgpackageversion 9.3" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-srpm93: prep
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." --sign \
-	--define "_buildrootdir $(HOME)/rpm93/BUILDROOT" \
-	--define "pgmajorversion 93" --define "pginstdir /usr/pgsql-9.3"  --define "pgpackageversion 9.3" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfsrpm93: prep
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm93/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm93/BUILDROOT" \
-	--define "pgmajorversion 93" --define "pginstdir /usr/pgsql-9.3"  --define "pgpackageversion 9.3" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfnosignsrpm93: prep
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_buildrootdir $(HOME)/rpm93/BUILDROOT" \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm93/SRPMS" \
-	--define "pgmajorversion 93" --define "pginstdir /usr/pgsql-9.3"  --define "pgpackageversion 9.3" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-rpm93: prep
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm93/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 93" --define "pginstdir /usr/pgsql-9.3" --define "pgpackageversion 9.3" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nosignbuild93: bfnosignsrpm93
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm93/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm93/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm93/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm93/RPMS/" \
-	--define "pgmajorversion 93" --define "pginstdir /usr/pgsql-9.3" --define "pgpackageversion 9.3" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepbuild93:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm93/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm93/BUILDROOT" \
-	--define "pgmajorversion 93" --define "pginstdir /usr/pgsql-9.3" --define "pgpackageversion 9.3" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm93/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm93/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm93/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm93/RPMS/" --sign \
-	--define "pgmajorversion 93" --define "pginstdir /usr/pgsql-9.3" --define "pgpackageversion 9.3" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nopreprpm93:
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm93/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 93" --define "pginstdir /usr/pgsql-9.3" --define "pgpackageversion 9.3" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepsrpm93:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." \
-	--define "_buildrootdir $(HOME)/rpm93/BUILDROOT" \
-	--define "pgmajorversion 93" --define "pginstdir /usr/pgsql-9.3" --define "pgpackageversion 9.3" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
diff --git a/rpm/redhat/common/Makefile.global-PG94 b/rpm/redhat/common/Makefile.global-PG94
deleted file mode 100644
index b3bb69426..000000000
--- a/rpm/redhat/common/Makefile.global-PG94
+++ /dev/null
@@ -1,103 +0,0 @@
-#################################
-# Makefile for PostgreSQL 9.4	#
-# packaging	  	 	#
-# https://yum.postgresql.org	#
-#			   	#
-# Devrim Gunduz		   	#
-# devrim@gunduz.org	   	#
-#################################
-#			 	#
-#				#
-# build target is for      	#
-# RPM buildfarm		   	#
-#			   	#
-#			   	#
-#################################
-
-
-## PostgreSQL 9.4
-
-build94: bfsrpm94
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm94/BUILDROOT" \
-	--define "_builddir $(HOME)/rpm94/BUILD" \
-	--define "_srcrpmdir $(HOME)/rpm94/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm94/RPMS/" --sign \
-	--define "pgmajorversion 94" --define "pginstdir /usr/pgsql-9.4" --define "pgpackageversion 9.4" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-srpm94: prep
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." --sign \
-	--define "_buildrootdir $(HOME)/rpm94/BUILDROOT" \
-	--define "pgmajorversion 94" --define "pginstdir /usr/pgsql-9.4"  --define "pgpackageversion 9.4" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfsrpm94: prep
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm94/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm94/BUILDROOT" \
-	--define "pgmajorversion 94" --define "pginstdir /usr/pgsql-9.4"  --define "pgpackageversion 9.4" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfnosignsrpm94: prep
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_buildrootdir $(HOME)/rpm94/BUILDROOT" \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm94/SRPMS" \
-	--define "pgmajorversion 94" --define "pginstdir /usr/pgsql-9.4"  --define "pgpackageversion 9.4" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-rpm94: prep
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm94/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 94" --define "pginstdir /usr/pgsql-9.4" --define "pgpackageversion 9.4" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nosignbuild94: bfnosignsrpm94
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm94/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm94/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm94/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm94/RPMS/" \
-	--define "pgmajorversion 94" --define "pginstdir /usr/pgsql-9.4" --define "pgpackageversion 9.4" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepbuild94:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm94/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm94/BUILDROOT" \
-	--define "pgmajorversion 94" --define "pginstdir /usr/pgsql-9.4" --define "pgpackageversion 9.4" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm94/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm94/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm94/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm94/RPMS/" --sign \
-	--define "pgmajorversion 94" --define "pginstdir /usr/pgsql-9.4" --define "pgpackageversion 9.4" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nopreprpm94:
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm94/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 94" --define "pginstdir /usr/pgsql-9.4" --define "pgpackageversion 9.4" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepsrpm94:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." \
-	--define "_buildrootdir $(HOME)/rpm94/BUILDROOT" \
-	--define "pgmajorversion 94" --define "pginstdir /usr/pgsql-9.4" --define "pgpackageversion 9.4" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
diff --git a/rpm/redhat/common/Makefile.global-PG95 b/rpm/redhat/common/Makefile.global-PG95
deleted file mode 100644
index 0c2b29a4d..000000000
--- a/rpm/redhat/common/Makefile.global-PG95
+++ /dev/null
@@ -1,103 +0,0 @@
-#################################
-# Makefile for PostgreSQL 9.5	#
-# packaging	  	 	#
-# https://yum.postgresql.org	#
-#			   	#
-# Devrim Gunduz		   	#
-# devrim@gunduz.org	   	#
-#################################
-#			 	#
-#				#
-# build target is for      	#
-# RPM buildfarm		   	#
-#			   	#
-#			   	#
-#################################
-
-
-## PostgreSQL 9.5
-
-build95: bfsrpm95
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm95/BUILDROOT" \
-	--define "_builddir $(HOME)/rpm95/BUILD" \
-	--define "_srcrpmdir $(HOME)/rpm95/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm95/RPMS/" --sign \
-	--define "pgmajorversion 95" --define "pginstdir /usr/pgsql-9.5" --define "pgpackageversion 9.5" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-srpm95: prep
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." --sign \
-	--define "_buildrootdir $(HOME)/rpm95/BUILDROOT" \
-	--define "pgmajorversion 95" --define "pginstdir /usr/pgsql-9.5"  --define "pgpackageversion 9.5" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfsrpm95: prep
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm95/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm95/BUILDROOT" \
-	--define "pgmajorversion 95" --define "pginstdir /usr/pgsql-9.5"  --define "pgpackageversion 9.5" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfnosignsrpm95: prep
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_buildrootdir $(HOME)/rpm95/BUILDROOT" \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm95/SRPMS" \
-	--define "pgmajorversion 95" --define "pginstdir /usr/pgsql-9.5"  --define "pgpackageversion 9.5" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-rpm95: prep
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm95/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 95" --define "pginstdir /usr/pgsql-9.5" --define "pgpackageversion 9.5" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nosignbuild95: bfnosignsrpm95
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm95/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm95/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm95/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm95/RPMS/" \
-	--define "pgmajorversion 95" --define "pginstdir /usr/pgsql-9.5" --define "pgpackageversion 9.5" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepbuild95:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm95/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm95/BUILDROOT" \
-	--define "pgmajorversion 95" --define "pginstdir /usr/pgsql-9.5" --define "pgpackageversion 9.5" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm95/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm95/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm95/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm95/RPMS/" --sign \
-	--define "pgmajorversion 95" --define "pginstdir /usr/pgsql-9.5" --define "pgpackageversion 9.5" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nopreprpm95:
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm95/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 95" --define "pginstdir /usr/pgsql-9.5" --define "pgpackageversion 9.5" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepsrpm95:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." \
-	--define "_buildrootdir $(HOME)/rpm95/BUILDROOT" \
-	--define "pgmajorversion 95" --define "pginstdir /usr/pgsql-9.5" --define "pgpackageversion 9.5" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
diff --git a/rpm/redhat/common/Makefile.global-PG96 b/rpm/redhat/common/Makefile.global-PG96
deleted file mode 100644
index 09e4593a5..000000000
--- a/rpm/redhat/common/Makefile.global-PG96
+++ /dev/null
@@ -1,110 +0,0 @@
-#################################
-# Makefile for PostgreSQL 9.6	#
-# packaging	  	 	#
-# https://yum.postgresql.org	#
-#			   	#
-# Devrim Gunduz		   	#
-# devrim@gunduz.org	   	#
-#################################
-#			 	#
-#				#
-# build target is for      	#
-# RPM buildfarm		   	#
-#			   	#
-#			   	#
-#################################
-
-
-## PostgreSQL 9.6
-
-prep96:
-	if [ -f dead.package ]; then echo "This package is marked as dead. Build won't continue"; exit 1; fi
-	# Update spec file, patches, etc, before running spectool:
-	git pull
-	# Use spectool to download source files, especially tarballs.
-	spectool -g -S --define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6" --define "pgpackageversion 9.6" $(SPECFILE)
-
-build96: bfsrpm96
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm96/BUILDROOT" \
-	--define "_builddir $(HOME)/rpm96/BUILD" \
-	--define "_srcrpmdir $(HOME)/rpm96/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm96/RPMS/" --sign \
-	--define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6" --define "pgpackageversion 9.6" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-srpm96: prep96
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." --sign \
-	--define "_buildrootdir $(HOME)/rpm96/BUILDROOT" \
-	--define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6"  --define "pgpackageversion 9.6" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfsrpm96: prep96
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm96/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm96/BUILDROOT" \
-	--define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6"  --define "pgpackageversion 9.6" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfnosignsrpm96: prep96
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_buildrootdir $(HOME)/rpm96/BUILDROOT" \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm96/SRPMS" \
-	--define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6"  --define "pgpackageversion 9.6" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-rpm96: prep96
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm96/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6" --define "pgpackageversion 9.6" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nosignbuild96: bfnosignsrpm96
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm96/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm96/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm96/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm96/RPMS/" \
-	--define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6" --define "pgpackageversion 9.6" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepbuild96:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm96/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm96/BUILDROOT" \
-	--define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6" --define "pgpackageversion 9.6" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm96/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm96/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm96/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm96/RPMS/" --sign \
-	--define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6" --define "pgpackageversion 9.6" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nopreprpm96:
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm96/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6" --define "pgpackageversion 9.6" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepsrpm96:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." \
-	--define "_buildrootdir $(HOME)/rpm96/BUILDROOT" \
-	--define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6" --define "pgpackageversion 9.6" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
diff --git a/rpm/redhat/common/Makefile.global-PG96-testing b/rpm/redhat/common/Makefile.global-PG96-testing
deleted file mode 100644
index ee3a9d8c0..000000000
--- a/rpm/redhat/common/Makefile.global-PG96-testing
+++ /dev/null
@@ -1,110 +0,0 @@
-#################################
-# Makefile for PostgreSQL 9.6	#
-# testing packaging	 	#
-# https://yum.postgresql.org	#
-#			   	#
-# Devrim Gunduz		   	#
-# devrim@gunduz.org	   	#
-#################################
-#			 	#
-#				#
-# build target is for      	#
-# RPM buildfarm		   	#
-#			   	#
-#			   	#
-#################################
-
-
-## PostgreSQL 9.6 Testing
-
-prep96testing:
-	if [ -f dead.package ]; then echo "This package is marked as dead. Build won't continue"; exit 1; fi
-	# Update spec file, patches, etc, before running spectool:
-	git pull
-	# Use spectool to download source files, especially tarballs.
-	spectool -g -S --define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6" --define "pgpackageversion 9.6" $(SPECFILE)
-
-build96testing: bfsrpm96testing
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm96testing/BUILDROOT" \
-	--define "_builddir $(HOME)/rpm96testing/BUILD" \
-	--define "_srcrpmdir $(HOME)/rpm96testing/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm96testing/RPMS/" --sign \
-	--define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6" --define "pgpackageversion 9.6" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-srpm96testing: prep96
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." --sign \
-	--define "_buildrootdir $(HOME)/rpm96testing/BUILDROOT" \
-	--define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6"  --define "pgpackageversion 9.6" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfsrpm96testing: prep96
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm96testing/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm96testing/BUILDROOT" \
-	--define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6"  --define "pgpackageversion 9.6" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-bfnosignsrpm96testing: prep96
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_buildrootdir $(HOME)/rpm96testing/BUILDROOT" \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm96testing/SRPMS" \
-	--define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6"  --define "pgpackageversion 9.6" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-rpm96testing: prep96
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm96testing/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6" --define "pgpackageversion 9.6" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nosignbuild96testimg: bfnosignsrpm96testing
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm96testing/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm96testing/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm96testing/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm96testing/RPMS/" \
-	--define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6" --define "pgpackageversion 9.6" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepbuild96testing:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir $(HOME)/rpm96testing/SRPMS" --sign \
-	--define "_buildrootdir $(HOME)/rpm96testing/BUILDROOT" \
-	--define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6" --define "pgpackageversion 9.6" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(HOME)/rpm96testing/BUILD" \
-	--define "_buildrootdir $(HOME)/rpm96testing/BUILDROOT" \
-	--define "_srcrpmdir $(HOME)/rpm96testing/SRPMS" \
-	--define "_rpmdir $(HOME)/rpm96testing/RPMS/" --sign \
-	--define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6" --define "pgpackageversion 9.6" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-nopreprpm96testing:
-	rpmbuild --define "_sourcedir $(PWD)" \
-	--define "_specdir $(PWD)" \
-	--define  "_builddir $(PWD)" \
-	--define "_buildrootdir $(HOME)/rpm96testing/BUILDROOT" \
-	--define "_srcrpmdir $(PWD)" \
-	--define "_rpmdir $(PWD)" \
-	--define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6" --define "pgpackageversion 9.6" \
-	--define "dist $(DIST)" -bb $(SPECFILE)
-
-noprepsrpm96testing:
-	rpmbuild --define "_sourcedir ." --define "_specdir ." \
-	--define "_builddir ." --define "_srcrpmdir ." \
-	--define "_buildrootdir $(HOME)/rpm96testing/BUILDROOT" \
-	--define "pgmajorversion 96" --define "pginstdir /usr/pgsql-9.6" --define "pgpackageversion 9.6" \
-	--define "_rpmdir ." --define "dist $(DIST)" --nodeps -bs $(SPECFILE)
-
-- 
2.23.0

